==> esentity-0.1.58.tar.gz: esentity-0.1.58/esentity/encoder.py <==
#coding: utf-8
from flask.json import JSONEncoder                                                                                                    
from datetime import date

class IsoJSONEncoder(JSONEncoder):                                                                                                    
    def default(self, obj):                                                                                                           
        try:                                                                                                                          
            if isinstance(obj, date):                                                                                                 
                return obj.isoformat()                                                                                                
            iterable = iter(obj)                                                                                                      
        except TypeError:                                                                                                             
            pass                                                                                                                      
        else:                                                                                                                         
            return list(iterable)                                                                                                     
        return JSONEncoder.default(self, obj)

==> esentity-0.2.35.tar.gz: esentity-0.2.35/esentity/encoder.py <==
#coding: utf-8
from flask.json import JSONEncoder                                                                                                    
from datetime import date

class IsoJSONEncoder(JSONEncoder):                                                                                                    
    def default(self, obj):                                                                                                           
        try:                                                                                                                          
            if isinstance(obj, date):                                                                                                 
                return obj.isoformat().replace('+00:00', 'Z')
            iterable = iter(obj)                                                                                                      
        except TypeError:                                                                                                             
            pass                                                                                                                      
        else:                                                                                                                         
            return list(iterable)                                                                                                     
        return JSONEncoder.default(self, obj)
